Class: Google::Apis::CloudfunctionsV1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudfunctions_v1/classes.rb,
lib/google/apis/cloudfunctions_v1/representations.rb,
lib/google/apis/cloudfunctions_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



908
909
910
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


893
894
895
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 893

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::CloudfunctionsV1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



898
899
900
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 898

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


906
907
908
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 906

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



913
914
915
916
917
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 913

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end