Class: Google::Apis::CloudfunctionsV1::OperationMetadataV1

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudfunctions_v1/classes.rb,
lib/google/apis/cloudfunctions_v1/representations.rb,
lib/google/apis/cloudfunctions_v1/representations.rb

Overview

Metadata describing an Operation

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadataV1

Returns a new instance of OperationMetadataV1.



1098
1099
1100
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#build_idString

The Cloud Build ID of the function created or updated by an API call. This field is only populated for Create and Update operations. Corresponds to the JSON property buildId

Returns:

  • (String)


1057
1058
1059
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1057

def build_id
  @build_id
end

#build_nameString

The Cloud Build Name of the function deployment. This field is only populated for Create and Update operations. projects//locations//builds/. Corresponds to the JSON property buildName

Returns:

  • (String)


1063
1064
1065
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1063

def build_name
  @build_name
end

#requestHash<String,Object>

The original request that started the operation. Corresponds to the JSON property request

Returns:

  • (Hash<String,Object>)


1068
1069
1070
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1068

def request
  @request
end

#source_tokenString

An identifier for Firebase function sources. Disclaimer: This field is only supported for Firebase function deployments. Corresponds to the JSON property sourceToken

Returns:

  • (String)


1074
1075
1076
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1074

def source_token
  @source_token
end

#targetString

Target of the operation - for example projects/project-1/locations/region-1/ functions/function-1 Corresponds to the JSON property target

Returns:

  • (String)


1080
1081
1082
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1080

def target
  @target
end

#typeString

Type of operation. Corresponds to the JSON property type

Returns:

  • (String)


1085
1086
1087
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1085

def type
  @type
end

#update_timeString

The last update timestamp of the operation. Corresponds to the JSON property updateTime

Returns:

  • (String)


1090
1091
1092
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1090

def update_time
  @update_time
end

#version_idFixnum

Version id of the function created or updated by an API call. This field is only populated for Create and Update operations. Corresponds to the JSON property versionId

Returns:

  • (Fixnum)


1096
1097
1098
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1096

def version_id
  @version_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1103

def update!(**args)
  @build_id = args[:build_id] if args.key?(:build_id)
  @build_name = args[:build_name] if args.key?(:build_name)
  @request = args[:request] if args.key?(:request)
  @source_token = args[:source_token] if args.key?(:source_token)
  @target = args[:target] if args.key?(:target)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version_id = args[:version_id] if args.key?(:version_id)
end