Class: Google::Apis::CloudfunctionsV1::CloudFunctionsService
- Inherits:
-
Google::Apis::Core::BaseService
- Object
- Google::Apis::Core::BaseService
- Google::Apis::CloudfunctionsV1::CloudFunctionsService
- Defined in:
- lib/google/apis/cloudfunctions_v1/service.rb
Overview
Cloud Functions API
Manages lightweight user-provided functions executed in response to events.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://cloudfunctions.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#call_function(name, call_function_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::CallFunctionResponse
Synchronously invokes a deployed Cloud Function.
-
#create_project_location_function(location, cloud_function_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::Operation
Creates a new function.
-
#delete_project_location_function(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::Operation
Deletes a function with the given name from the specified project.
-
#generate_function_download_url(name, generate_download_url_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::GenerateDownloadUrlResponse
Returns a signed URL for downloading deployed function source code.
-
#generate_function_upload_url(parent, generate_upload_url_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::GenerateUploadUrlResponse
Returns a signed URL for uploading a function source code.
-
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_function(name, version_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::CloudFunction
Returns a function with the given name from the requested project.
-
#get_project_location_function_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::Policy
Gets the IAM access control policy for a function.
-
#initialize ⇒ CloudFunctionsService
constructor
A new instance of CloudFunctionsService.
-
#list_operations(filter: nil, name: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_functions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::ListFunctionsResponse
Returns a list of functions that belong to the requested project.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_function(name, cloud_function_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::Operation
Updates existing function.
-
#set_function_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::Policy
Sets the IAM access control policy on the specified function.
-
#test_function_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::TestIamPermissionsResponse
Tests the specified permissions against the IAM access control policy for a function.
Constructor Details
#initialize ⇒ CloudFunctionsService
Returns a new instance of CloudFunctionsService.
47 48 49 50 51 52 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-cloudfunctions_v1', client_version: Google::Apis::CloudfunctionsV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#call_function(name, call_function_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::CallFunctionResponse
Synchronously invokes a deployed Cloud Function. To be used for testing purposes as very limited traffic is allowed. For more information on the actual limits, refer to Rate Limits.
205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 205 def call_function(name, call_function_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:call', ) command.request_representation = Google::Apis::CloudfunctionsV1::CallFunctionRequest::Representation command.request_object = call_function_request_object command.response_representation = Google::Apis::CloudfunctionsV1::CallFunctionResponse::Representation command.response_class = Google::Apis::CloudfunctionsV1::CallFunctionResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_function(location, cloud_function_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::Operation
Creates a new function. If a function with the given name already exists in
the specified project, the long running operation will return ALREADY_EXISTS
error.
241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 241 def create_project_location_function(location, cloud_function_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+location}/functions', ) command.request_representation = Google::Apis::CloudfunctionsV1::CloudFunction::Representation command.request_object = cloud_function_object command.response_representation = Google::Apis::CloudfunctionsV1::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV1::Operation command.params['location'] = location unless location.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_function(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::Operation
Deletes a function with the given name from the specified project. If the given function is used by some trigger, the trigger will be updated to remove this function.
275 276 277 278 279 280 281 282 283 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 275 def delete_project_location_function(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::CloudfunctionsV1::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_function_download_url(name, generate_download_url_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::GenerateDownloadUrlResponse
Returns a signed URL for downloading deployed function source code. The URL is only valid for a limited period and should be used within minutes after generation. For more information about the signed URL usage see: https://cloud. google.com/storage/docs/access-control/signed-urls
310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 310 def generate_function_download_url(name, generate_download_url_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:generateDownloadUrl', ) command.request_representation = Google::Apis::CloudfunctionsV1::GenerateDownloadUrlRequest::Representation command.request_object = generate_download_url_request_object command.response_representation = Google::Apis::CloudfunctionsV1::GenerateDownloadUrlResponse::Representation command.response_class = Google::Apis::CloudfunctionsV1::GenerateDownloadUrlResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_function_upload_url(parent, generate_upload_url_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::GenerateUploadUrlResponse
Returns a signed URL for uploading a function source code. For more
information about the signed URL usage see: https://cloud.google.com/storage/
docs/access-control/signed-urls. Once the function source code upload is
complete, the used signed URL should be provided in CreateFunction or
UpdateFunction request as a reference to the function source code. When
uploading source code to the generated signed URL, please follow these
restrictions: * Source file type should be a zip file. * Source file size
should not exceed 100MB limit. * No credentials should be attached - the
signed URLs provide access to the target bucket using internal service
identity; if credentials were attached, the identity from the credentials
would be used, but that identity does not have permissions to upload files to
the URL. When making a HTTP PUT request, these two headers need to be
specified: * content-type: application/zip * x-goog-content-length-range: 0,
104857600 And this header SHOULD NOT be specified: * Authorization: Bearer
YOUR_TOKEN
358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 358 def generate_function_upload_url(parent, generate_upload_url_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/functions:generateUploadUrl', ) command.request_representation = Google::Apis::CloudfunctionsV1::GenerateUploadUrlRequest::Representation command.request_object = generate_upload_url_request_object command.response_representation = Google::Apis::CloudfunctionsV1::GenerateUploadUrlResponse::Representation command.response_class = Google::Apis::CloudfunctionsV1::GenerateUploadUrlResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 75 def get_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::CloudfunctionsV1::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_function(name, version_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::CloudFunction
Returns a function with the given name from the requested project.
397 398 399 400 401 402 403 404 405 406 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 397 def get_project_location_function(name, version_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::CloudfunctionsV1::CloudFunction::Representation command.response_class = Google::Apis::CloudfunctionsV1::CloudFunction command.params['name'] = name unless name.nil? command.query['versionId'] = version_id unless version_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_function_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::Policy
Gets the IAM access control policy for a function. Returns an empty policy if the function exists and does not have a policy set.
442 443 444 445 446 447 448 449 450 451 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 442 def get_project_location_function_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::CloudfunctionsV1::Policy::Representation command.response_class = Google::Apis::CloudfunctionsV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_operations(filter: nil, name: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 120 def list_operations(filter: nil, name: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/operations', ) command.response_representation = Google::Apis::CloudfunctionsV1::ListOperationsResponse::Representation command.response_class = Google::Apis::CloudfunctionsV1::ListOperationsResponse command.query['filter'] = filter unless filter.nil? command.query['name'] = name unless name.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_functions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::ListFunctionsResponse
Returns a list of functions that belong to the requested project.
484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 484 def list_project_location_functions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/functions', ) command.response_representation = Google::Apis::CloudfunctionsV1::ListFunctionsResponse::Representation command.response_class = Google::Apis::CloudfunctionsV1::ListFunctionsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::ListLocationsResponse
Lists information about the supported locations for this service.
167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 167 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::CloudfunctionsV1::ListLocationsResponse::Representation command.response_class = Google::Apis::CloudfunctionsV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_function(name, cloud_function_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::Operation
Updates existing function.
520 521 522 523 524 525 526 527 528 529 530 531 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 520 def patch_project_location_function(name, cloud_function_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::CloudfunctionsV1::CloudFunction::Representation command.request_object = cloud_function_object command.response_representation = Google::Apis::CloudfunctionsV1::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_function_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::Policy
Sets the IAM access control policy on the specified function. Replaces any existing policy.
557 558 559 560 561 562 563 564 565 566 567 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 557 def set_function_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::CloudfunctionsV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::CloudfunctionsV1::Policy::Representation command.response_class = Google::Apis::CloudfunctionsV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_function_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV1::TestIamPermissionsResponse
Tests the specified permissions against the IAM access control policy for a function. If the function does not exist, this will return an empty set of permissions, not a NOT_FOUND error.
594 595 596 597 598 599 600 601 602 603 604 |
# File 'lib/google/apis/cloudfunctions_v1/service.rb', line 594 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::CloudfunctionsV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::CloudfunctionsV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::CloudfunctionsV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |