Class: Google::Apis::CloudfunctionsV1::SecretVersion
- Inherits:
-
Object
- Object
- Google::Apis::CloudfunctionsV1::SecretVersion
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudfunctions_v1/classes.rb,
lib/google/apis/cloudfunctions_v1/representations.rb,
lib/google/apis/cloudfunctions_v1/representations.rb
Overview
Configuration for a single version.
Instance Attribute Summary collapse
-
#path ⇒ String
Relative path of the file under the mount path where the secret value for this version will be fetched and made available.
-
#version ⇒ String
Version of the secret (version number or the string 'latest').
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecretVersion
constructor
A new instance of SecretVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecretVersion
Returns a new instance of SecretVersion.
1289 1290 1291 |
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#path ⇒ String
Relative path of the file under the mount path where the secret value for this
version will be fetched and made available. For example, setting the
mount_path as '/etc/secrets' and path as /secret_foo would mount the secret
value file at /etc/secrets/secret_foo.
Corresponds to the JSON property path
1280 1281 1282 |
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1280 def path @path end |
#version ⇒ String
Version of the secret (version number or the string 'latest'). It is
preferable to use latest version with secret volumes as secret value changes
are reflected immediately.
Corresponds to the JSON property version
1287 1288 1289 |
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1287 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1294 1295 1296 1297 |
# File 'lib/google/apis/cloudfunctions_v1/classes.rb', line 1294 def update!(**args) @path = args[:path] if args.key?(:path) @version = args[:version] if args.key?(:version) end |